--
-- InteractiveWindows
-- Specialization for InteractiveWindows
--
-- @author      Manuel Leithner (SFM-Modding)
-- @version     v3.0
-- @date        24/10/12
-- @history:    v1.0 - Initial version
--              v2.0 - converted to ls2011
--              v3.0 - converted to ls2013
--
-- free for noncommerical-usage
--

InteractiveWindows = {};

function InteractiveWindows.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(InteractiveControl, specializations) and SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end;

function InteractiveWindows:load(savegame)

    local i=0;
    while true do
        local windowName = string.format("vehicle.interactiveComponents.windows.window(%d)", i);
        if not hasXMLProperty(self.xmlFile, windowName) then
            break;
        end;
        local animation = getXMLString(self.xmlFile, windowName .. "#animName");
        local name = Utils.getNoNil(g_i18n:getText(getXMLString(self.xmlFile, windowName .. "#name")), "ERROR");
        local mark = Utils.indexToObject(self.components, getXMLString(self.xmlFile, windowName .. "#mark"));
        local highlight = getChildAt(mark, 0);
        local size = Utils.getNoNil(getXMLFloat(self.xmlFile, windowName .. "#size"), 0.1);
        local onMessage = g_i18n:getText(Utils.getNoNil(getXMLString(self.xmlFile, windowName .. "#onMessage"), "ic_button_on"));
        local offMessage =  g_i18n:getText(Utils.getNoNil(getXMLString(self.xmlFile, windowName .. "#offMessage") , "ic_button_off"));
        local window = Window:new(highlight, name, animation, mark, size, self, onMessage, offMessage, self.infoBar);
        window.synch = Utils.getNoNil(getXMLBool(self.xmlFile, windowName .. "#synch"), true);
        table.insert(self.interactiveObjects, window);
        i = i + 1;
    end;
    ac_on = false;
    door_open = false;
end;

function InteractiveWindows:delete()
end;

function InteractiveWindows:mouseEvent(posX, posY, isDown, isUp, button)
end;

function InteractiveWindows:keyEvent(unicode, sym, modifier, isDown)
end;

function InteractiveWindows:update(dt)
end;

function InteractiveWindows:draw()
end;



--
-- Window Class
-- Specifies an interactive window
--
-- SFM-Modding
-- @author  Manuel Leithner
-- @date  26/12/09
--

Window = {};
Window.modir = g_currentModDirectory;

-- Flag values for state changes
ac_on = false;

-- Sound files are loaded
acSnd = createSample("AC"); 
loadSample(acSnd, Utils.getFilename("Sounds/AC.wav", Window.modir), false);
dSnd = createSample("DS");
loadSample(dSnd, Utils.getFilename("Sounds/DoorOpen.wav", Window.modir), false);
dCSnd = createSample("DCS");
loadSample(dCSnd, Utils.getFilename("Sounds/DoorClose.wav", Window.modir), false);


function Window:new(highlight, name, animation, mark, size, vehicle, onMessage, offMessage, infobar)

    local Window_mt = Class(Window, InteractiveComponentInterface);
    local instance = InteractiveComponentInterface:new(nil, highlight, name, mark, size, onMessage, offMessage, infobar, Window_mt);
    instance.vehicle = vehicle;
    instance.animation = animation;
    name = name;
    v = vehicle;
  
    return instance;
end;

function Window:delete()
    InteractiveComponentInterface.delete(self);
end;

function Window:mouseEvent(posX, posY, isDown, isUp, button)
    InteractiveComponentInterface.mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function Window:keyEvent(unicode, sym, modifier, isDown)
    InteractiveComponentInterface.keyEvent(self, unicode, sym, modifier, isDown);
end;

function Window:update(dt)
    InteractiveComponentInterface.update(self, dt);
end;

function Window:draw()
    InteractiveComponentInterface.draw(self);
end;

function Window:doAction(noEventSend, forceAction)
    InteractiveComponentInterface.doAction(self, forceAction);
    local dir = 1;
    if not self.isOpen  then
        dir = -1;
    end;
    self.vehicle:playAnimation(self.animation, dir, Utils.clamp(self.vehicle:getAnimationTime(self.animation), 0, 1), true);
	if self.vehicle:getIsActive() then
	    if self.name == "air conditioner" then
		    if ac_on == true then
			setSampleVolume(acSnd, 0.0);
			ac_on = false;
		    else	    
			playSample(acSnd, 0, .4, 0);
			ac_on = true;
		    end;
	    end;
	    if self.name == "door" then
		    if self.vehicle:getAnimationTime(self.animation) == 1 then
			    playSample(dCSnd, 1, 1, 0);
		    else
			    playSample(dSnd, 1, 1, 0);
		    end;
	    end;
    end;
end;

function Window:onEnter()
    InteractiveComponentInterface.onEnter(self);
end;

function Window:onExit()
    InteractiveComponentInterface.onExit(self);
end;

function Window:setActive()
    InteractiveComponentInterface.setActive(self, isActive);
end;

function Window:setVisible(isVisible)
    InteractiveComponentInterface.setVisible(self, isVisible);
end;
